@@ -30,9 +30,6 @@ from Iuppiter.DjangoUtil import (extendInstalledApps,
 from oscar import get_core_apps
 from oscar import OSCAR_MAIN_TEMPLATE_DIR
 
-oscarDefaultsPackages = __import__(
-    'oscar.defaults', globals(), locals(), [], -1).__dict__
-
 from django.utils.translation import ugettext_lazy as _
 
 def attachSettings(settingsDict, enablePaypal=False):
@@ -141,8 +138,10 @@ def attachSettings(settingsDict, enablePaypal=False):
     #=========================================================================
 
     #=========================================================================
-    for package in oscarDefaultsPackages:
-        update(settingsDict, package)
+    # Oscar default settings 
+    oscarDefaultsPackages = __import__(
+        'oscar.defaults', globals(), locals(), [], -1).__dict__
+    update(settingsDict, oscarDefaultsPackages)
     #=========================================================================
 
     #=========================================================================
